@@ -855,7 +855,7 @@ current test run, if any"
 and return the parsed result as a sexp"
   (unless options (setq options ""))
   (ps/parse-sexp
-   (shell-command-to-string
+   (ps/shell-command-to-string
     (format "perly_sense %s \"--file=%s\" --row=%s --col=%s %s --width_display=%s"
             command
             (buffer-file-name)
@@ -871,7 +871,7 @@ and return the parsed result as a sexp"
 options, and return the parsed result as a sexp"
   (unless options (setq options ""))
   (ps/parse-sexp
-   (shell-command-to-string
+   (ps/shell-command-to-string
     (format "perly_sense %s %s --width_display=%s"
             command
             options
@@ -879,6 +879,16 @@ options, and return the parsed result as a sexp"
 
 
 
+(defun ps/shell-command-to-string (command)
+  "Run command and return the response"
+  (let ((response (shell-command-to-string command)))
+;;    (message "Called (%s), got (%s)" command response)
+    response
+    )
+  )
+
+
+
 (defun ps/go-to-method-new ()
   "Go to the 'new' method."
   (interactive)
@@ -1704,14 +1714,14 @@ or go to the Bookmark at point"
 
 
 
-(provide 'perly-sense)
-
-
-
+(load "perly-sense-visualize-coverage")
 (if ps/load-flymake (load "perly-sense-flymake"))
 
 
 
+(provide 'perly-sense)
+
+
 
 
 
